@@ -97,6 +97,9 @@ if ( ! CUSTOM_TAGS ) {
 			'src' => true,
 		),
 		'b' => array(),
+		'bdo' => array(
+			'dir' => true,
+		),
 		'big' => array(),
 		'blockquote' => array(
 			'cite' => true,
@@ -180,6 +183,15 @@ if ( ! CUSTOM_TAGS ) {
 			'lang' => true,
 			'xml:lang' => true,
 		),
+		'form' => array(
+			'action' => true,
+			'accept' => true,
+			'accept-charset' => true,
+			'enctype' => true,
+			'method' => true,
+			'name' => true,
+			'target' => true,
+		),
 		'h1' => array(
 			'align' => true,
 		),
@@ -532,7 +544,7 @@ function wp_kses( $string, $allowed_html, $allowed_protocols = array() ) {
  * @return string Filtered attribute.
  */
 function wp_kses_one_attr( $string, $element ) {
-	$uris = wp_kses_uri_attributes();
+	$uris = array('xmlns', 'profile', 'href', 'src', 'cite', 'classid', 'codebase', 'data', 'usemap', 'longdesc', 'action');
 	$allowed_html = wp_kses_allowed_html( 'post' );
 	$allowed_protocols = wp_allowed_protocols();
 	$string = wp_kses_no_null( $string, array( 'slash_zero' => 'keep' ) );
@@ -598,7 +610,6 @@ function wp_kses_one_attr( $string, $element ) {
  * Return a list of allowed tags and attributes for a given context.
  *
  * @since 3.5.0
- * @since 5.0.1 `form` removed as allowable HTML tag.
  *
  * @global array $allowedposttags
  * @global array $allowedtags
@@ -628,27 +639,7 @@ function wp_kses_allowed_html( $context = '' ) {
 	switch ( $context ) {
 		case 'post':
 			/** This filter is documented in wp-includes/kses.php */
-			$tags = apply_filters( 'wp_kses_allowed_html', $allowedposttags, $context );
-
-			// 5.0.1 removed the `<form>` tag, allow it if a filter is allowing it's sub-elements `<input>` or `<select>`.
-			if ( ! CUSTOM_TAGS && ! isset( $tags['form'] ) && ( isset( $tags['input'] ) || isset( $tags['select'] ) ) ) {
-				$tags = $allowedposttags;
-
-				$tags['form'] = array(
-					'action' => true,
-					'accept' => true,
-					'accept-charset' => true,
-					'enctype' => true,
-					'method' => true,
-					'name' => true,
-					'target' => true,
-				);
-
-				/** This filter is documented in wp-includes/kses.php */
-				$tags = apply_filters( 'wp_kses_allowed_html', $tags, $context );
-			}
-
-			return $tags;
+			return apply_filters( 'wp_kses_allowed_html', $allowedposttags, $context );
 
 		case 'user_description':
 		case 'pre_user_description':
@@ -731,56 +722,6 @@ function wp_kses_split( $string, $allowed_html, $allowed_protocols ) {
 	return preg_replace_callback( '%(<!--.*?(-->|$))|(<[^>]*(>|$)|>)%', '_wp_kses_split_callback', $string );
 }
 
-/**
- * Helper function listing HTML attributes containing a URL.
- *
- * This function returns a list of all HTML attributes that must contain
- * a URL according to the HTML specification.
- *
- * This list includes URI attributes both allowed and disallowed by KSES.
- *
- * @link https://developer.mozilla.org/en-US/docs/Web/HTML/Attributes
- *
- * @since 5.0.1
- *
- * @return array HTML attributes that must include a URL.
- */
-function wp_kses_uri_attributes() {
-	$uri_attributes = array(
-		'action',
-		'archive',
-		'background',
-		'cite',
-		'classid',
-		'codebase',
-		'data',
-		'formaction',
-		'href',
-		'icon',
-		'longdesc',
-		'manifest',
-		'poster',
-		'profile',
-		'src',
-		'usemap',
-		'xmlns',
-	);
-
-	/**
-	 * Filters the list of attributes that are required to contain a URL.
-	 *
-	 * Use this filter to add any `data-` attributes that are required to be
-	 * validated as a URL.
-	 *
-	 * @since 5.0.1
-	 *
-	 * @param array $uri_attributes HTML attributes requiring validation as a URL.
-	 */
-	$uri_attributes = apply_filters( 'wp_kses_uri_attributes', $uri_attributes );
-
-	return $uri_attributes;
-}
-
 /**
  * Callback for wp_kses_split.
  *
@@ -976,7 +917,7 @@ function wp_kses_hair($attr, $allowed_protocols) {
 	$attrarr = array();
 	$mode = 0;
 	$attrname = '';
-	$uris = wp_kses_uri_attributes();
+	$uris = array('xmlns', 'profile', 'href', 'src', 'cite', 'classid', 'codebase', 'data', 'usemap', 'longdesc', 'action');
 
 	// Loop through the whole attribute list
 
@@ -1756,10 +1697,10 @@ function safecss_filter_attr( $css, $deprecated = '' ) {
 	'border-right-style', 'border-right-width', 'border-spacing', 'border-style', 'border-top',
 	'border-top-color', 'border-top-style', 'border-top-width', 'border-width', 'caption-side',
 	'clear', 'cursor', 'direction', 'font', 'font-family', 'font-size', 'font-style',
-	'font-variant', 'font-weight', 'height', 'letter-spacing', 'line-height', 'margin-bottom',
+	'font-variant', 'font-weight', 'height', 'min-height','max-height' , 'letter-spacing', 'line-height', 'margin-bottom',
 	'margin-left', 'margin-right', 'margin-top', 'overflow', 'padding', 'padding-bottom',
 	'padding-left', 'padding-right', 'padding-top', 'text-decoration', 'text-indent', 'vertical-align',
-	'width' ) );
+	'width', 'min-width', 'max-width' ) );
 
 	if ( empty($allowed_attr) )
 		return $css;
